import {Hex} from 'viem'
export * from './abi'
/**
 * The eco protocol chain configuration type. Represents
 * all the deployed contracts on a chain.
 * 
 * @packageDocumentation
 * @module index
 */
export type EcoChainConfig = {
  Prover: Hex
  IntentSource: Hex
  Inbox: Hex
  HyperProver: Hex
}

/**
 * The chain ids for the eco protocol
 * 
 * @packageDocumentation
 * @module index
 */
export type EcoChainIds = "11155420" | "11155420-pre"

/**
 * This file contains the addresses of the contracts deployed on the EcoProtocol network
 * for the current npm package release. The addresses are generated by the deploy script.
 * 
 * @packageDocumentation
 * @module index
*/
export const EcoProtocolAddresses: Record<EcoChainIds, EcoChainConfig> = 
  {
    "11155420": {
      "Prover": "0x43735e208e2e4BFa50c0D50e295c229d8EE23d2f",
      "IntentSource": "0x71fAd8a7C94B34412eaCB24f88b973BD33C88103",
      "Inbox": "0xA6369D30cc7F5f31c79a14E0EA073D74d12773B2",
      "HyperProver": "0x60B6dF55Ed3Cd852B03349144CD46541Cbde2Fb9"
    },
    "11155420-pre": {
      "Prover": "0xEa0d7cDb3Faa88A793c96E13592b5259d82Ebc9B",
      "IntentSource": "0xC11F8e07FED667AB958d478a9aab0facd2beA8D5",
      "Inbox": "0x1DC6ABDaf714C90c1712822B5073Ec3A3f45a3Ce",
      "HyperProver": "0xcdababaa89753A25e7692Eb4657F050c7EdcE3E0"
    }
  } as const
